@@ -1,6 +1,6 @@
 import pytest
 
-def _api(access_token='__MASTODON_PY_TEST_ACCESS_TOKEN', version="2.8.0", version_check_mode="created"):
+def _api(access_token='__MASTODON_PY_TEST_ACCESS_TOKEN', version="3.0.1", version_check_mode="created"):
     import mastodon
     return mastodon.Mastodon(
             api_base_url='http://localhost:3000',
@@ -23,6 +23,10 @@ def api_low_version():
 def api2():
     return _api(access_token='__MASTODON_PY_TEST_ACCESS_TOKEN_2')
 
+@pytest.fixture
+def api3():
+    return _api(access_token='__MASTODON_PY_TEST_ACCESS_TOKEN_3')
+
 @pytest.fixture
 def api_anonymous():
     return _api(access_token=None)
